Crate leptos_i18n_router

Crate leptos_i18n_router 

This crate contain anything related to routing for the leptos_i18n crate.

Macros

i18n_path
Create a route segment that is possible to define based on a locale.

Functions

I18nRoute
Required Props