Crate leptos_i18n_router
leptos_
i18n_
router
0.6.0
All Items
Crate Items
Macros
Functions
Crate
leptos_
i18n_
router
This crate contain anything related to routing for the
leptos_i18n
crate.
Macros

i18n_
path
Create a route segment that is possible to define based on a locale.
Functions

I18n
Route
Required Props